@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.4.0
+ *             Automatically Tuned Linear Algebra Software v3.5.0
  *                    (C) Copyright 1998 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -209,8 +209,8 @@ void ATL_mprintf(int np, ...)
       for (i=0; i < np; i++) fp[i] = va_arg(argptr, FILE *);
       form = va_arg(argptr, char *);
       #ifdef ATL_UseStringVarArgs
-         assert(strlen(ln) < 1024);/* sanity test only, will not stop overrun */
          vsprintf(ln, form, argptr);
+         assert(strlen(ln) < 1024);/* sanity test only, will not stop overrun */
          va_end(argptr);
          for (i=0; i < np; i++) if (fp[i]) fprintf(fp[i], ln);
       #else
@@ -488,7 +488,7 @@ void GoToTown(char *sdir, char *mmdir, int L1DEF)
          ATL_mprintf(2, fpsum, stdout,
 "      The best matmul kernel was %s, written by %s\n", fnam, ln);
          ATL_mprintf(2, fpsum, stdout,
-"      This gave performance of %.2fMFLOPS (%5.2f%% of apparent peak)\n",
+"      Performance: %.2fMFLOPS (%5.2f percent of apparent peak)\n",
                     mfU, (mfU/mfp)*100.0);
          mmmf = mfU;
       }
@@ -498,7 +498,7 @@ void GoToTown(char *sdir, char *mmdir, int L1DEF)
 "      %cL1MATMUL: lat=%d, nb=%d, mu=%d, nu=%d, ku=%d, if=%d, nf=%d;\n",
                  pre, lat, nb, mu, nu, ku, ifetch, nfetch);
          ATL_mprintf(2, fpsum, stdout,
-"                 This gave performance of %.2f (%5.2f%% of apparent peak)\n",
+"                 Performance: %.2f (%5.2f percent of apparent peak)\n",
                  mf, (mf/mfp)*100.0);
          mmmf = mf;
       }
@@ -536,14 +536,14 @@ void GoToTown(char *sdir, char *mmdir, int L1DEF)
             fprintf(stdout,"                 ForceFetch=%d, ifetch=%d nfetch=%d\n",
                     ffetch, ifetch, nfetch);
             fprintf(stdout,
-"                 Performance = %.2f (%5.2f%% of copy matmul, %5.2f%% of peak)\n",
+"                 Performance = %.2f (%5.2f of copy matmul, %5.2f of peak)\n",
                      mf, (mf/mmmf)*100.0, (mf / mfp)*100.0);
             fprintf(fpsum,
 "      mm%c%c   : ma=%d, lat=%d, nb=%d, mu=%d, nu=%d ku=%d, ff=%d, if=%d, nf=%d\n",
                     TR[ia], TR[ib], muladd, lat, nb, mu, nu, ku,
                     ffetch, ifetch, nfetch);
             fprintf(fpsum,
-"               Performance = %.2f (%5.2f%% of copy matmul, %5.2f%% of peak)\n",
+"               Performance = %.2f (%5.2f of copy matmul, %5.2f of peak)\n",
                   mf, (mf/mmmf)*100.0, (mf / mfp)*100.0);
          }
       }
@@ -649,10 +649,10 @@ void GoToTown(char *sdir, char *mmdir, int L1DEF)
                   "      gemvN : chose routine %d:%s written by %s\n",
                   j, ln3, tnam);
       ATL_mprintf(2, fpsum, stdout,
-                  "              Yunroll=%d, Xunroll=%d, using %d%% of L1\n",
+         "              Yunroll=%d, Xunroll=%d, using %d percent of L1\n",
                   mu, nu, il1mul);
       ATL_mprintf(2, fpsum, stdout,
-"              Performance = %.2f (%5.2f%% of copy matmul, %5.2f%% of peak)\n",
+"              Performance = %.2f (%5.2f of copy matmul, %5.2f of peak)\n",
               mf, (mf/mmmf)*100.0, (mf / mfp)*100.0);
       ATL_Cassert(fgets(ln, 256, fp), "MVTUNE", NULL);
       ATL_Cassert(sscanf(ln, " %d %d %d %d %d %lf %s \"%[^\"]", &j, &i,
@@ -662,10 +662,10 @@ void GoToTown(char *sdir, char *mmdir, int L1DEF)
                   "      gemvT : chose routine %d:%s written by %s\n",
                   j, ln3, tnam);
       ATL_mprintf(2, fpsum, stdout,
-                  "              Yunroll=%d, Xunroll=%d, using %d%% of L1\n",
+         "              Yunroll=%d, Xunroll=%d, using %d percent of L1\n",
                   mu, nu, il1mul);
       ATL_mprintf(2, fpsum, stdout,
-"              Performance = %.2f (%5.2f%% of copy matmul, %5.2f%% of peak)\n",
+"              Performance = %.2f (%5.2f of copy matmul, %5.2f of peak)\n",
               mf, (mf/mmmf)*100.0, (mf / mfp)*100.0);
 
       ATL_mprintf(2, fpsum, stdout,"\n\n   STAGE 2-%d-6: GER TUNE\n", ip+1);
@@ -689,10 +689,10 @@ void GoToTown(char *sdir, char *mmdir, int L1DEF)
       ATL_mprintf(2, fpsum, stdout,
               "      ger : chose routine %d:%s written by %s\n", j, ln3, tnam);
       ATL_mprintf(2, fpsum, stdout,
-              "            mu=%d, nu=%d, using %5.2f%% of L1 Cache\n",
+              "            mu=%d, nu=%d, using %5.2f percent of L1 Cache\n",
               mu, nu, il1mul*0.01);
       ATL_mprintf(2, fpsum, stdout,
-"              Performance = %.2f (%5.2f%% of copy matmul, %5.2f%% of peak)\n",
+"              Performance = %.2f (%5.2f of copy matmul, %5.2f of peak)\n",
               mf, (mf/mmmf)*100.0, (mf / mfp)*100.0);
    }
    ATL_mprintf(2, fpsum, stdout,"\n\nSTAGE 3: GENERAL LIBRARY BUILD\n");
