@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.4.0
+ *             Automatically Tuned Linear Algebra Software v3.5.0
  *                    (C) Copyright 1997 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -100,9 +100,9 @@ void matgen(int M, int N, TYPE *A, int lda, int seed)
       Mjoin(PATL,aliased_gemm)(TA, TB, m, n, k, al, A, lda, B, ldb, be, C, ldc)
 #endif
 
-int mmcase(int TEST, char TA, char TB, int M, int N, int K, SCALAR alpha,
-           TYPE *A, int lda, TYPE *B, int ldb, SCALAR beta, TYPE *C, int ldc,
-           TYPE *D, int ldd)
+int mmcase(int TEST, int CACHESIZE, char TA, char TB, int M, int N, int K,
+	   SCALAR alpha, TYPE *A, int lda, TYPE *B, int ldb, SCALAR beta,
+	   TYPE *C, int ldc, TYPE *D, int ldd)
 {
    char *pc;
 #ifdef TREAL
@@ -119,11 +119,13 @@ int mmcase(int TEST, char TA, char TB, int M, int N, int K, SCALAR alpha,
    TYPE maxval, f1, ferr;
    static TYPE feps=0.0;
    static int itst=1;
-   int *L2, nL2=(1.3*L2SIZE)/sizeof(int);
+   /*int *L2, nL2=(1.3*L2SIZE)/sizeof(int);*/
    enum ATLAS_TRANS TAc, TBc;
+   double l2ret;
 
    if (!TEST) D = C;
-   if (nL2) L2 = malloc(nL2*sizeof(int));
+   /*if (nL2) L2 = malloc(nL2*sizeof(int));*/
+   l2ret = ATL_flushcache( CACHESIZE );
    if (TA == 'n' || TA == 'N')
    {
       matgen(M, K, A, lda, K*1112);
@@ -154,11 +156,15 @@ int mmcase(int TEST, char TA, char TB, int M, int N, int K, SCALAR alpha,
    printmat("C0", M, N, C, ldc);
 #endif
 
-   if (L2) /* invalidate L2 cache */
-   {
-      for (i=0; i != nL2; i++) L2[i] = 0.0;
-      for (i=0; i != nL2; i++) j += L2[i];
-   }
+   /*
+     if (L2)
+     {
+     for (i=0; i != nL2; i++) L2[i] = 0.0;
+     for (i=0; i != nL2; i++) j += L2[i];
+     }*/
+
+   /* invalidate L2 cache */
+   l2ret = ATL_flushcache( -1 );
 
    t0 = time00();
    trusted_gemm(TAc, TBc, M, N, K, alpha, A, lda, B, ldb, beta, C, ldc);
@@ -179,11 +185,8 @@ int mmcase(int TEST, char TA, char TB, int M, int N, int K, SCALAR alpha,
 #ifndef TIMEONLY
    matgen(M, N, D, ldd, M*N);
 
-   if (L2)
-   {
-      for (i=0; i != nL2; i++) L2[i] = 0.0;  /* invalidate L2 cache */
-      for (i=0; i != nL2; i++) j += L2[i];  /* invalidate L2 cache */
-   }
+   /* invalidate L2 cache */
+   l2ret = ATL_flushcache( -1 );
 
    t0 = time00();
    test_gemm(TAc, TBc, M, N, K, alpha, A, lda, B, ldb, beta, D, ldd);
@@ -265,12 +268,13 @@ int mmcase(int TEST, char TA, char TB, int M, int N, int K, SCALAR alpha,
    itst++;
    PASSED = 1;
 #endif
-   free(L2);
+   /*free(L2);*/
+   l2ret = ATL_flushcache( 0 );
    return(PASSED);
 }
 
-int mmcase0(int MFLOP, char TA, char TB, int M, int N, int K, SCALAR alpha,
-            int lda, int ldb, SCALAR beta, int ldc)
+int mmcase0(int MFLOP, int CACHESIZE, char TA, char TB, int M, int N, int K,
+	    SCALAR alpha, int lda, int ldb, SCALAR beta, int ldc)
 {
    char *pc;
 #ifdef TREAL
@@ -347,7 +351,8 @@ int mmcase0(int MFLOP, char TA, char TB, int M, int N, int K, SCALAR alpha,
    incC = ldc*N;
    inc = incA + incB + incC;
    i = M*K + K*N + M*N;  /* amount of inc actually referenced */
-   nmat = ((L2SIZE/ATL_sizeof) + i)/i;
+   /* This is a hack; change to use of flushcache instead. */
+   nmat = ((CACHESIZE/ATL_sizeof) + i)/i;
    vp = malloc(ATL_MulBySize(nmat*inc)+ATL_Cachelen);
    ATL_assert(vp);
    C = c = ATL_AlignPtr(vp);
@@ -415,7 +420,7 @@ int mmcase0(int MFLOP, char TA, char TB, int M, int N, int K, SCALAR alpha,
 
 void PrintUsage(char *nam)
 {
-   fprintf(stderr, "USAGE: %s -Side <nsides> L/R -Uplo <nuplo> L/U -Atrans <ntrans> n/t/c -Btrans <ntrans> n/t/c -Diag <ndiags> N/U -M <m1> <mN> <minc> -N <n1> <nN> <ninc> <k1> <kN> <kinc> -n <n> -m <m> -k <k> -a <nalphas> <alpha1> ... <alphaN> -b <nbetas> <beta1> ... <betaN> -Test <0/1> -F <mflops>\n", nam);
+   fprintf(stderr, "USAGE: %s -Side <nsides> L/R -Uplo <nuplo> L/U -Atrans <ntrans> n/t/c -Btrans <ntrans> n/t/c -Diag <ndiags> N/U -M <m1> <mN> <minc> -N <n1> <nN> <ninc> <k1> <kN> <kinc> -n <n> -m <m> -k <k> -a <nalphas> <alpha1> ... <alphaN> -b <nbetas> <beta1> ... <betaN> -Test <0/1> -F <mflops> -C <cachesize>\n", nam);
    exit(-1);
 }
 
@@ -426,7 +431,7 @@ void GetFlags(int nargs, char *args[], int *TEST, int *nside,
               enum ATLAS_DIAG **Diag, int *M0, int *MN, int *Minc,
               int *N0, int *NN, int *Ninc, int *K0, int *KN, int *Kinc,
               int *nalphas, TYPE **alphas, int *nbetas, TYPE **betas,
-              int *LDA_IS_M, int *MFLOP)
+              int *LDA_IS_M, int *MFLOP, int *CACHESIZE)
 
 {
    char ch;
@@ -438,6 +443,11 @@ void GetFlags(int nargs, char *args[], int *TEST, int *nside,
    *M0 = *N0 = *K0 = -1;
    *nuplo = *nta = *ntb = *nside = *ndiag = *nalphas = *nbetas = -1;
    *MFLOP = *LDA_IS_M = 0;
+#ifdef L2SIZE
+   *CACHESIZE = L2SIZE;               /* Size of largest cache to flush */
+#else
+   *CACHESIZE = 4*1024*1024;
+#endif
 
    for (i=1; i < nargs; i++)
    {
@@ -446,6 +456,10 @@ void GetFlags(int nargs, char *args[], int *TEST, int *nside,
       case 'F':
          *MFLOP = atoi(args[++i]);
          break;
+      case 'C':
+            if( args[i+1] == NULL ) PrintUsage( args[0] );
+	    *CACHESIZE = 1024*atoi(args[++i]);
+            break;
       case 'S':
          *nside = atoi(args[++i]);
          *Side = malloc(*nside * sizeof(int));
@@ -650,11 +664,12 @@ main(int nargs, char *args[])
    enum ATLAS_UPLO *Uplo;
    enum ATLAS_TRANS *TransA, *TransB, TAc, TBc;
    enum ATLAS_DIAG *Diag;
+   int CACHESIZE;
 
    GetFlags(nargs, args, &TEST, &nside, &Side, &nuplo, &Uplo,
             &nTA, &TransA, &nTB, &TransB, &ndiag, &Diag,
             &M0, &MN, &incM, &N0, &NN, &incN, &K0, &KN, &incK,
-            &nalph, &alph, &nbeta, &beta, &LDA_IS_M, &MFLOP);
+            &nalph, &alph, &nbeta, &beta, &LDA_IS_M, &MFLOP,&CACHESIZE);
 
    if (M0 == -1)
    {
@@ -685,10 +700,10 @@ main(int nargs, char *args[])
  */
    if (MFLOP)
    {
-      mmcase0(10, 'n', 'n', 100, 100, 100, alp1, 100, 100, bet1, 100);
-      mmcase0(10, 'n', 't', 100, 100, 100, alp1, 100, 100, bet1, 100);
-      mmcase0(10, 't', 'n', 100, 100, 100, alp1, 100, 100, bet1, 100);
-      mmcase0(10, 't', 't', 100, 100, 100, alp1, 100, 100, bet1, 100);
+      mmcase0(10, 1, 'n', 'n', 100, 100, 100, alp1, 100, 100, bet1, 100);
+      mmcase0(10, 1, 'n', 't', 100, 100, 100, alp1, 100, 100, bet1, 100);
+      mmcase0(10, 1, 't', 'n', 100, 100, 100, alp1, 100, 100, bet1, 100);
+      mmcase0(10, 1, 't', 't', 100, 100, 100, alp1, 100, 100, bet1, 100);
    }
    else
    {
@@ -757,25 +772,27 @@ main(int nargs, char *args[])
                         if (MFLOP)
                         {
                            ipass++;
-                           #ifdef TREAL
-                              mmcase0(MFLOP, TA, TB, m, n, k, alph[ia],
-                                      lda, ldb, beta[ib], ldc);
-                           #else
-                              mmcase0(MFLOP, TA, TB, m, n, k, alph+(ia SHIFT),
-                                      lda, ldb, beta+(ib SHIFT), ldc);
-                           #endif
+#ifdef TREAL
+                              mmcase0(MFLOP, CACHESIZE, TA, TB, m, n, k,
+				      alph[ia], lda, ldb, beta[ib], ldc);
+#else
+                              mmcase0(MFLOP, CACHESIZE, TA, TB, m, n, k,
+				      alph+(ia SHIFT), lda, ldb,
+				      beta+(ib SHIFT), ldc);
+#endif
                         }
                         else
                         {
-                           #ifdef TREAL
-                              ipass += mmcase(TEST, TA, TB, m, n, k,
-                                              alph[ia], A, lda, B, ldb,
+#ifdef TREAL
+                              ipass += mmcase(TEST, CACHESIZE, TA, TB, m,
+					      n, k, alph[ia], A, lda, B, ldb,
                                               beta[ib], C, ldc, D,ldc);
-                           #else
-                              ipass += mmcase(TEST, TA, TB, m, n, k,
-                                              alph+(ia SHIFT), A, lda, B, ldb,
-                                              beta+(ib SHIFT), C, ldc, D,ldc);
-                           #endif
+#else
+                              ipass += mmcase(TEST, CACHESIZE, TA, TB, m,
+					      n, k, alph+(ia SHIFT), A,
+					      lda, B, ldb, beta+(ib SHIFT),
+					      C, ldc, D,ldc);
+#endif
                         }
                      }
                   }
