@@ -1,3 +1,6 @@
+#if !defined(ATL_GAS_x8632) &&  !defined(ATL_GAS_x8664)
+   #error "This kernel requires gas x86 assembler!"
+#endif
 /*  The mening of the defined macros is as follows:
  *  VECLEN:         The length of a singleprecision vector register
  *  vec_add:        Add to single precision vectors. 
