@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.4.0
+ *             Automatically Tuned Linear Algebra Software v3.5.0
  *                    (C) Copyright 1999 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -43,7 +43,7 @@ void catlas_saxpby(const int N, const float alpha, const float *X,
 
    if (N > 0)
    {
-      if (incX > 0 && incY > 0) goto L1;
+      if (incX >= 0 && incY >= 0) goto L1;
       else if (incY < 0)
       {
          if (incX < 0) { incx = -incX; incy = -incY; }
