@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.4.0
+ *             Automatically Tuned Linear Algebra Software v3.5.0
  *                    (C) Copyright 2001 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -38,7 +38,7 @@ void F77axpby(const F77_INTEGER *N, const TYPE *alpha, const TYPE *X,
 
    if (*N > 0)
    {
-      if (incx > 0 && incy > 0) goto L1;
+      if (incx >= 0 && incy >= 0) goto L1;
       else if (incy < 0)
       {
          if (incx < 0) { incx = -incx; incy = -incy; }
