@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.4.0
+ *             Automatically Tuned Linear Algebra Software v3.5.0
  *                    (C) Copyright 1997 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -149,8 +149,10 @@ void Mjoin(Mjoin(PATL,aliased_gemm),TATB)
           ldpa = K;
        #endif
     }
-    Mjoin(PATU,usergemm)(ETA, ETB, M, N, K, alpha, pA, ldpa, pB, ldpb,
-                         beta, C, ldc);
+    if (Mjoin(PATU,usergemm)(ETA, ETB, M, N, K, alpha, pA, ldpa, pB, ldpb,
+                             beta, C, ldc))
+       ATL_assert(Mjoin(PATL,NCmmJIK)(ETA, ETB, M, N, K, alpha, pA, ldpa,
+                                      pB, ldpb, beta, C, ldc)==0);
 #else
 
    #ifdef TCPLX
