@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.4.0
+ *             Automatically Tuned Linear Algebra Software v3.5.0
  *                    (C) Copyright 1997 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -36,6 +36,10 @@
 #define ATL_row2blkT Mjoin(Mjoin(PATL,row2blkT),NM)
 #define ATL_row2blkT2 Mjoin(Mjoin(PATL,row2blkT2),NM)
 
+#if defined (DREAL) && defined(ATL_GAS_x8664) && 0
+void ATL_row2blkT_NB(const int M, const int N, const TYPE *A, const int lda,
+                     TYPE *V, const TYPE alpha);
+#else
 static void ATL_row2blkT_NB
    (const int M, const int N, const TYPE *A, const int lda, TYPE *V,
     const TYPE alpha0)
@@ -81,6 +85,7 @@ L1:
       pA1 += lda2;
    }
 }
+#endif
 
 static void ATL_row2blkT_KB
    (const int M, const int N, const TYPE *A, const int lda, TYPE *V,
