@@ -17,7 +17,7 @@
    #define lda2 lda
 #endif
 /*
- *             Automatically Tuned Linear Algebra Software v3.4.0
+ *             Automatically Tuned Linear Algebra Software v3.5.0
  *                    (C) Copyright 1999 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -54,7 +54,7 @@ static int ATL_potrfL_4(TYPE *A, const int lda)
    TYPE L44=*pA3;
    int iret=0;
 
-   if (L11 >= ATL_rzero)
+   if (L11 > ATL_rzero)
    {
       *A = L11 = sqrt(L11);
       L11 = ATL_rone / L11;
@@ -63,7 +63,7 @@ static int ATL_potrfL_4(TYPE *A, const int lda)
       L41 *= L11;
       A[1] = L21; A[2] = L31; A[3] = L41;
       L22 -= L21*L21;
-      if (L22 >= ATL_rzero)
+      if (L22 > ATL_rzero)
       {
          *pA1 = L22 = sqrt(L22);
          L22 = ATL_rone / L22;
@@ -71,13 +71,13 @@ static int ATL_potrfL_4(TYPE *A, const int lda)
          L42 = (L42 - L41*L21) * L22;
          L33 -= L31*L31 + L32*L32;
          pA1[1] = L32; pA1[2] = L42;
-         if (L33 >= ATL_rzero)
+         if (L33 > ATL_rzero)
          {
             *pA2 = L33 = sqrt(L33);
             L43 = (L43 - L41*L31 - L42*L32) / L33;
             L44 -= L41*L41 + L42*L42 + L43*L43;
             pA2[1] = L43;
-            if (L44 >= ATL_rzero)
+            if (L44 > ATL_rzero)
             {
                *pA3 = sqrt(L44);
                return(0);
@@ -99,7 +99,7 @@ static int ATL_potrfL_3(TYPE *A, const int lda)
    register TYPE L33=*pA2;
    int iret=0;
 
-   if (L11 >= ATL_rzero)
+   if (L11 > ATL_rzero)
    {
       *A = L11 = sqrt(L11);
       L11 = ATL_rone / L11;
@@ -107,13 +107,13 @@ static int ATL_potrfL_3(TYPE *A, const int lda)
       L31 *= L11;
       A[1] = L21; A[2] = L31;
       L22 -= L21*L21;
-      if (L22 >= ATL_rzero)
+      if (L22 > ATL_rzero)
       {
          L22 = sqrt(L22);
          L32 = (L32 - L31*L21) / L22;
          L33 -= L31*L31 + L32*L32;
          *pA1 = L22; pA1[1] = L32;
-         if (L33 >= ATL_rzero)
+         if (L33 > ATL_rzero)
          {
             *pA2 = sqrt(L33);
             return(0);
@@ -129,13 +129,18 @@ static int ATL_potrfL_3(TYPE *A, const int lda)
 static int ATL_potrfL_2(TYPE *A, const int lda)
 {
    register TYPE L11=*A, L21=A[1], L22 = A[lda+1];
-   *A = L11 = sqrt(L11);
-   A[1] = L21 = L21 / L11;
-   L22 -= L21*L21;
-   if (L22 >= ATL_rzero)
+
+   if (L11 > ATL_rzero)
    {
-      A[lda+1] = sqrt(L22);
-      return(0);
+      *A = L11 = sqrt(L11);
+      A[1] = L21 = L21 / L11;
+      L22 -= L21*L21;
+      if (L22 > ATL_rzero)
+      {
+         A[lda+1] = sqrt(L22);
+         return(0);
+      }
+      else return(2);
    }
    else return(1);
 }
