@@ -17,7 +17,7 @@
    #define lda2 lda
 #endif
 /*
- *             Automatically Tuned Linear Algebra Software v3.4.0
+ *             Automatically Tuned Linear Algebra Software v3.5.0
  *                    (C) Copyright 1999 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -55,7 +55,7 @@ static int ATL_potrfU_4(TYPE *A, const int lda)
    TYPE L44 = pA3[3];
    int iret=0;
 
-   if (L11 >= ATL_rzero)
+   if (L11 > ATL_rzero)
    {
       *A = L11 = sqrt(L11);
       L11 = ATL_rone / L11;
@@ -64,7 +64,7 @@ static int ATL_potrfU_4(TYPE *A, const int lda)
       L41 *= L11;
       *pA1 = L21; *pA2 = L31; *pA3 = L41;
       L22 -= L21*L21;
-      if (L22 >= ATL_rzero)
+      if (L22 > ATL_rzero)
       {
          pA1[1] = L22 = sqrt(L22);
          L22 = ATL_rone / L22;
@@ -72,13 +72,13 @@ static int ATL_potrfU_4(TYPE *A, const int lda)
          L42 = (L42 - L41*L21) * L22;
          L33 -= L31*L31 + L32*L32;
          pA2[1] = L32; pA3[1] = L42;
-         if (L33 >= ATL_rzero)
+         if (L33 > ATL_rzero)
          {
             pA2[2] = L33 = sqrt(L33);
             L43 = (L43 - L41*L31 - L42*L32) / L33;
             L44 -= L41*L41 + L42*L42 + L43*L43;
             pA3[2] = L43;
-            if (L44 >= ATL_rzero)
+            if (L44 > ATL_rzero)
             {
                pA3[3] = sqrt(L44);
                return(0);
@@ -100,7 +100,7 @@ static int ATL_potrfU_3(TYPE *A, const int lda)
    register TYPE L33=pA2[2];
    int iret=0;
 
-   if (L11 >= ATL_rzero)
+   if (L11 > ATL_rzero)
    {
       *A = L11 = sqrt(L11);
       L11 = ATL_rone / L11;
@@ -108,13 +108,13 @@ static int ATL_potrfU_3(TYPE *A, const int lda)
       L31 *= L11;
       *pA1 = L21; *pA2 = L31;
       L22 -= L21*L21;
-      if (L22 >= ATL_rzero)
+      if (L22 > ATL_rzero)
       {
          L22 = sqrt(L22);
          L32 = (L32 - L31*L21) / L22;
          L33 -= L31*L31 + L32*L32;
          pA1[1] = L22; pA2[1] = L32;
-         if (L33 >= ATL_rzero)
+         if (L33 > ATL_rzero)
          {
             pA2[2] = sqrt(L33);
             return(0);
@@ -131,13 +131,18 @@ static int ATL_potrfU_2(TYPE *A, const int lda)
 {
    TYPE *pA1 = A+lda;
    register TYPE L11=*A, L21=*pA1, L22 = pA1[1];
-   *A = L11 = sqrt(L11);
-   *pA1 = L21 = L21 / L11;
-   L22 -= L21*L21;
-   if (L22 >= ATL_rzero)
+
+   if (L11 > ATL_rzero)
    {
-      pA1[1] = sqrt(L22);
-      return(0);
+      *A = L11 = sqrt(L11);
+      *pA1 = L21 = L21 / L11;
+      L22 -= L21*L21;
+      if (L22 > ATL_rzero)
+      {
+         pA1[1] = sqrt(L22);
+         return(0);
+      }
+      else return(2);
    }
    else return(1);
 }
