@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.4.0
+ *             Automatically Tuned Linear Algebra Software v3.5.0
  *                      (C) Copyright 1999 Camm Maguire
  *
  * Redistribution and use in source and binary forms, with or without
@@ -29,8 +29,12 @@
  */
 
 #include "camm_util.h"
+#ifndef ATL_GAS_x8632
+   #error "This kernel requires gas x86-32 assembler!"
+#endif
 #include "camm_strat.h"
 
+
 #define VERS 1
 
 #if defined(DREAL) || defined(DCPLX)
