@@ -1,5 +1,6 @@
+
 /*
- *             Automatically Tuned Linear Algebra Software v3.4.0
+ *             Automatically Tuned Linear Algebra Software v3.5.0
  *                    (C) Copyright 2001 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -95,11 +96,12 @@ void ATL_USERMM
    vector float vA0, vA1, vA2, vA3, vB0, vB1, vB2, vB3;
    vector float  vC0_0, vC1_0, vC2_0, vC3_0, vC0_1, vC1_1, vC2_1, vC3_1,
                  vC0_2, vC1_2, vC2_2, vC3_2, vC0_3, vC1_3, vC2_3, vC3_3;
-   const vector float nzero =  (vector float)(-0.0f, -0.0f, -0.0f, -0.0f);
-
+   const vector float nzero =  VECTOR_INIT(-0.0f, -0.0f, -0.0f, -0.0f);
    #ifndef ATL_NoIEEE
-      vec_mtvscr((vector unsigned long)(0));
+      const vector int izero = VECTOR_INITI(0,0,0,0);
+      vec_mtvscr(izero);
    #endif
+
    vC = malloc(ATL_Cachelen + sizeof(float)*16);
    ATL_assert( vC && ( ((M>>2)<<2) == M ) && ( ((N>>2)<<2) == N ) );
    tC = ATL_AlignPtr(vC);
