@@ -1,5 +1,6 @@
+
 /*
- *             Automatically Tuned Linear Algebra Software v3.4.0
+ *             Automatically Tuned Linear Algebra Software v3.5.0
  *                    (C) Copyright 2001 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -79,7 +80,7 @@ void ATL_mmcu(const int M, const int N, const int K, const TYPE alpha,
    const float *pA0=A, *pB0=B;
    register float rC0_0;
    vector float vA0, vB0, vC0_0;
-   const vector float nzero =  (vector float)(-0.0f, -0.0f, -0.0f, -0.0f);
+   const vector float nzero =  VECTOR_INIT(-0.0f, -0.0f, -0.0f, -0.0f);
 
    i = cwrdKB>>24; /* size */
    j = (cwrdKB - (i<<24))>>16; /* count */
@@ -160,11 +161,13 @@ void ATL_USERMM
    vector float vA0, vA1, vA2, vA3, vB0, vB1, vB2, vB3;
    vector float  vC0_0, vC1_0, vC2_0, vC3_0, vC0_1, vC1_1, vC2_1, vC3_1,
                  vC0_2, vC1_2, vC2_2, vC3_2, vC0_3, vC1_3, vC2_3, vC3_3;
-   const vector float nzero =  (vector float)(-0.0f, -0.0f, -0.0f, -0.0f);
+   const vector float nzero = VECTOR_INIT(-0.0f, -0.0f, -0.0f, -0.0f);
 
    #ifndef ATL_NoIEEE /* turn on java/ieee mode */
-      vec_mtvscr((vector unsigned long)(0));
+      const vector int izero = VECTOR_INITI(0,0,0,0);
+      vec_mtvscr(izero);
    #endif
+
    vC = malloc(ATL_Cachelen + sizeof(float)*16);
    ATL_assert(vC);
    tC = ATL_AlignPtr(vC);
