@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.4.0
+ *             Automatically Tuned Linear Algebra Software v3.5.0
  *                    (C) Copyright 2000 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -30,6 +30,9 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <assert.h>
+#include <string.h>
+#include <ctype.h>
+#include <stddef.h>
 
 int LineIsCont(char *ln)
 {
@@ -136,9 +139,10 @@ int GetUserCase(char pre, int icase, int *iflag, int *mb, int *nb, int *kb,
 void GoGetThem(char *infile, char *outfile)
 {
    char ln[512], ln2[512], tnam[256], MCC[256], MMFLAGS[256];
-   char *chkfile = "FlagCheck.c";
+   char *chkfile = "FlagCheck.c", *sp, *sp2;
    FILE *fpin, *fpout;
-   int i, j, n, nmin=0;
+   int i, j, n, nmin=0, good;
+   int wass;
 
    fpout = fopen(chkfile, "w");
    assert(fpout);
@@ -154,17 +158,65 @@ void GoGetThem(char *infile, char *outfile)
    assert(fgets(ln, 512, fpin));
    for (i=0; i < n; i++)
    {
+      wass = 0;
       assert(fgets(ln, 512, fpin));
       if (LineIsCont(ln))
       {
          assert(fgets(MCC, 256, fpin));
          assert(fgets(MMFLAGS, 256, fpin));
          sprintf(ln2, "%s %s -c -DATL_BETA=1 %s\n", MCC, MMFLAGS, chkfile);
+/*
+ *       Substitute -x c for -x assembler or -x assembler-with-cpp
+ */
+         if (sp = strstr(ln2, "assembler"))
+         {
+            sp2 = strstr(ln2, "-x");
+            if (sp2 && ((ptrdiff_t) sp2) < ((ptrdiff_t) sp))
+            {
+               for (sp2 += 2; sp2 != sp; sp2++)
+                  if (!isspace(*sp2)) break;
+               if (sp2 == sp)
+               {
+                  wass = 1;
+                  sp[0] = 'c';
+                  for (j=1; j != 9; j++) sp[j] = ' ';
+                  if (strstr(sp, "assembler-with-cpp"))
+                  {
+                     wass = 2;
+                     for (; j != 18; j++) sp[j] = ' ';
+                  }
+               }
+            }
+         }
          for (j=0; ln2[j]; j++) if (ln2[j] == '\n') ln2[j] = ' ';
          ln2[j-1] = '\n';
          fprintf(stdout, "%s", ln2);
-         if (system(ln2) == 0)
+         if (!system(ln2))
          {
+            if (wass)
+            {
+               sp[ 0] = 'a';
+               sp[ 1] = 's';
+               sp[ 2] = 's';
+               sp[ 3] = 'e';
+               sp[ 4] = 'm';
+               sp[ 5] = 'b';
+               sp[ 6] = 'l';
+               sp[ 7] = 'e';
+               sp[ 8] = 'r';
+               if (wass > 1)
+               {
+                  sp[ 9] = '-';
+                  sp[10] = 'w';
+                  sp[11] = 'i';
+                  sp[12] = 't';
+                  sp[13] = 'h';
+                  sp[14] = '-';
+                  sp[15] = 'c';
+                  sp[16] = 'p';
+                  sp[17] = 'p';
+               }
+            }
             fputs(ln, fpout);
             fputs(MCC, fpout);
             fputs(MMFLAGS, fpout);
