@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.4.0
+ *             Automatically Tuned Linear Algebra Software v3.5.0
  *                    (C) Copyright 1999 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -126,41 +126,20 @@ void Mjoin(PATL,gemv0)
     const TYPE *A, const int lda, const TYPE *X, const int incX,
     const SCALAR beta, TYPE *Y, const int incY)
 {
-   int i, j;
-   const int M2 = M<<1, N2 = N<<1;
-   #if defined(BETAX) || defined(BETAXI0)
-      const TYPE rbeta = *beta, ibeta = beta[1];
-   #endif
-   register TYPE ra, ia, rx, ix, ry, iy;
+   int j;
+   const int lda2 = lda<<1, N2 = N<<1;
 
-   for (i=0; i != M2; i += 2)
+   #ifdef Conj_
+      #define axpycj Mjoin(PATL,axpyConj)
+      Mjoin(PATL,axpbyConj)(M, X, A, 1, beta, Y, 1);
+   #else
+      #define axpycj Mjoin(PATL,axpy)
+      Mjoin(PATL,axpby)(M, X, A, 1, beta, Y, 1);
+   #endif
+   if (N != 1)
    {
-      #ifdef BETA0
-         ry = iy = ATL_rzero;
-      #elif defined(BETAX)
-         rx = rbeta; ix = ibeta;
-         ra = Y[i]; ia = Y[i+1];
-         ry = ra * rx - ia * ix;
-         iy = ra * ix + ia * rx;
-      #else
-         ry = Y[i];
-         iy = Y[i+1];
-         #ifdef BETAXI0
-            rx = rbeta;
-            ry *= rx;
-            iy *= rx;
-         #endif
-      #endif
-      for(j=0; j != N2; j += 2)
-      {
-         ra = A[i+j*lda]; ia = A[i+j*lda+1];
-         rx = X[j]; ix = X[j+1];
-         ry += ra * rx;
-         iy += ra * ix;
-         ry MEQ ia * ix;
-         iy PEQ ia * rx;
-      }
-      Y[i] = ry;
-      Y[i+1] = iy;
+      A += lda2;
+      X += 2;
+      for (j=N-1; j; j--, A += lda2, X += 2) axpycj(M, X, A, 1, Y, 1);
    }
 }
