@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.4.0
+ *             Automatically Tuned Linear Algebra Software v3.5.0
  *                    (C) Copyright 1999 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,14 +37,12 @@ void Mjoin(Mjoin(Mjoin(Mjoin(Mjoin(PATL,gemvN),NM),_x1),BNM),_y1)
    (const int M, const int N, const SCALAR alpha, const TYPE *A, const int lda,
     const TYPE *X, const int incX, const SCALAR beta, TYPE *Y, const int incY)
 {
-   int i, j;
-   for (i=0; i != M; i++)
-   {
-      #ifdef BETA0
-         Y[i] = ATL_rzero;
-      #elif defined(BETAX)
-         Y[i] *= beta;
-      #endif
-      for (j=0; j != N; j++) Y[i] += A[i+j*lda] * X[j];
-   }
+   int j;
+
+   #ifdef BETA0
+      Mjoin(PATL,zero)(M, Y, 1);
+   #elif !defined(BETA1)
+      Mjoin(PATL,scal)(M, beta, Y, 1);
+   #endif
+   for (j=N; j; j--, A += lda, X++) Mjoin(PATL,axpy)(M, *X, A, 1, Y, 1);
 }
