@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.4.0
+ *             Automatically Tuned Linear Algebra Software v3.5.0
  *                    (C) Copyright 1999 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -417,206 +417,136 @@ static void gemvNle4(const int M, const int N, const TYPE *A, const int lda,
    }
 }
 
-void Mjoin(Mjoin(Mjoin(Mjoin(Mjoin(PATL,gemvN),NM),_x1),BNM),_y1)
-   (const int M, const int N, const SCALAR alpha, const TYPE *A, const int lda,
-    const TYPE *X, const int incX, const SCALAR beta, TYPE *Y, const int incY)
+static void gemv4x4(const int M, const int N, const TYPE *A, const int lda,
+                    const TYPE *X, const SCALAR beta, TYPE *Y)
 {
-   const int incA = lda<<1, incAm = 4 - ((N>>1)<<1)*lda;
-   const int m4 = (M>>2)<<2;
-   int n2, nr;
-   register TYPE y0, y1, y2, y3, z0, z1, z2, z3, x0, x1, m0, m1, m2, m3;
+   const int M4 = (M>>2)<<2, N4 = (N>>2)<<2, nr = N-N4;
+   const int incA = lda << 2, incAm = 4 - N4*lda;
+   const TYPE *stX = X + N4, *x;
+   const TYPE *A0 = A, *A1 = A + lda, *A2 = A1 + lda, *A3 = A2 + lda;
+   TYPE *stY = Y + M4;
    register TYPE a00, a10, a20, a30, a01, a11, a21, a31;
-   const TYPE *x, *stX = X + ((N>>1)<<1)-2, *A0 = A, *A1 = A + lda;
-   TYPE *stY = Y + m4;
+   register TYPE a02, a12, a22, a32, a03, a13, a23, a33;
+   register TYPE y0, y1, y2, y3, yy0, yy1, yy2, yy3;
+   register TYPE x0, x1, x2, x3;
 
    if (N > 4)
    {
-      n2 = ((N-4)>>1)<<1;
-      nr = N - n2;
-      if (m4)
+      if (M4)
       {
          do
          {
-            x = X + 2;
+            a00 = *A0; a01 = *A1;  a02 = *A2; a03 = *A3;
+            a10 = A0[1]; a11 = A1[1]; a12 = A2[1]; a13 = A3[1];
+            a20 = A0[2]; a21 = A1[2]; a22 = A2[2]; a23 = A3[2];
+            a30 = A0[3]; a31 = A1[3]; a32 = A2[3]; a33 = A3[3];
+            A0 += incA; A1 += incA; A2 += incA; A3 += incA;
             #ifdef BETA0
-               z0 = z1 = z2 = z3 = y0 = y1 = y2 = y3 = ATL_rzero;
+               yy0 = yy1 = yy2 = yy3 = y0 = y1 = y2 = y3 = ATL_rzero;
+            #elif defined BETAX
+               y0 = beta;
+               yy0 = *Y; yy1 = Y[1]; yy2 = Y[2];  yy3 = Y[3];
+               yy0 *= y0; yy1 *= y0; yy2 *= y0; yy3 *= y0;
+               y0 = y1 = y2 = y3 = ATL_rzero;
             #else
-               z0 = *Y;
-               z1 = Y[1];
-               z2 = Y[2];
-               z3 = Y[3];
-               #ifdef BETAX
-                  y0 = beta;
-                  z0 *= y0;
-                  z1 *= y0;
-                  z2 *= y0;
-                  z3 *= y0;
-               #endif
+               yy0 = *Y; yy1 = Y[1]; yy2 = Y[2];  yy3 = Y[3];
                y0 = y1 = y2 = y3 = ATL_rzero;
             #endif
-            x0 = *X;
-            x1 = X[1];
-            a00 = *A0;
-            a01 = *A1;
-            a10 = A0[1];
-            a11 = A1[1];
-            a20 = A0[2];
-            a21 = A1[2];
-            a30 = A0[3];
-            a31 = A1[3];
-            A0 += incA;
-            A1 += incA;
-            m0 = x0 * a00;
-            a00 = *A0;
-            m1 = x1 * a01;
-            a01 = *A1;
-            m2 = x0 * a10;
-            a10 = A0[1];
-            m3 = x1 * a11;
-            a11 = A1[1];
-            if (n2)
+            x0 = *X; x1 = X[1]; x2 = X[2]; x3 = X[3];
+            x = X + 4;
+            if (N4 != 4)
             {
                do
                {
-                  y0 += m0;
-                  m0 = x0 * a20;
-                  a20 = A0[2];
-                  z0 += m1;
-                  m1 = x1 * a21;
-                  a21 = A1[2];
-                  y1 += m2;
-                  m2 = x0 * a30;
-                  x0 = *x;
-                  a30 = A0[3];
-                  A0 += incA;
-                  z1 += m3;
-                  m3 = x1 * a31;
-                  x1 = x[1];
-                  a31 = A1[3];
-                  x += 2;
-                  A1 += incA;
+                  y0  += x0 * a00; a00 = *A0;
+                  yy0 += x1 * a01; a01 = *A1;
+                  y1  += x0 * a10; a10 = A0[1];
+                  yy1 += x1 * a11; a11 = A1[1];
+                  y2  += x0 * a20; a20 = A0[2];
+                  yy2 += x1 * a21; a21 = A1[2];
+                  y3  += x0 * a30; a30 = A0[3]; A0 += incA; x0 = *x;
+                  yy3 += x1 * a31; a31 = A1[3]; A1 += incA; x1 = x[1];
 
-                  y2 += m0;
-                  m0 = x0 * a00;
-                  a00 = *A0;
-                  z2 += m1;
-                  m1 = x1 * a01;
-                  a01 = *A1;
-                  y3 += m2;
-                  m2 = x0 * a10;
-                  a10 = A0[1];
-                  z3 += m3;
-                  m3 = x1 * a11;
-                  a11 = A1[1];
+                  y0  += x2 * a02; a02 = *A2;
+                  yy0 += x3 * a03; a03 = *A3;
+                  y1  += x2 * a12; a12 = A2[1];
+                  yy1 += x3 * a13; a13 = A3[1];
+                  y2  += x2 * a22; a22 = A2[2];
+                  yy2 += x3 * a23; a23 = A3[2];
+                  y3  += x2 * a32; a32 = A2[3]; A2 += incA; x2 = x[2];
+                  yy3 += x3 * a33; a33 = A3[3]; A3 += incA; x3 = x[3]; x += 4;
                }
-               while (x != stX);
+               while(x != stX);
             }
-            if (nr == 4)
+/*
+ *          Drain pipe
+ */
+            y0  += x0 * a00;
+            yy0 += x1 * a01;
+            y1  += x0 * a10;
+            yy1 += x1 * a11;
+            y2  += x0 * a20;
+            yy2 += x1 * a21;
+            y3  += x0 * a30;
+            yy3 += x1 * a31;
+
+            y0  += x2 * a02;
+            yy0 += x3 * a03;
+            y1  += x2 * a12;
+            yy1 += x3 * a13;
+            y2  += x2 * a22;
+            yy2 += x3 * a23;
+            y3  += x2 * a32;
+            yy3 += x3 * a33;
+/*
+ *          loop cleanup
+ */
+            switch(nr)
             {
-               y0 += m0;
-               m0 = x0 * a20;
-               a20 = A0[2];
-               z0 += m1;
-               m1 = x1 * a21;
-               a21 = A1[2];
-               y1 += m2;
-               m2 = x0 * a30;
+            case 1:
+               x0 = *x;
+               y0 += x0 * *A0;
+               y1 += x0 * A0[1];
+               y2 += x0 * A0[2];
+               y3 += x0 * A0[3];
+               break;
+            case 2:
                x0 = *x;
-               a30 = A0[3];
-               z1 += m3;
-               m3 = x1 * a31;
                x1 = x[1];
-               a31 = A1[3];
-
-               y2 += m0;
-               m0 = x0 * a00;
-               z2 += m1;
-               m1 = x1 * a01;
-               y3 += m2;
-               m2 = x0 * a10;
-               z3 += m3;
-               m3 = x1 * a11;
-
-               y0 += m0;
-               m0 = x0 * a20;
-               z0 += m1;
-               m1 = x1 * a21;
-               y1 += m2;
-               m2 = x0 * a30;
-               z1 += m3;
-               m3 = x1 * a31;
-
-               y2 += m0;
-               A0 += incA;
-               z2 += m1;
-               A1 += incA;
-               y3 += m2;
-               z3 += m3;
+               y0  += x0 * *A0;
+               yy0 += x1 * *A1;
+               y1  += x0 * A0[1];
+               yy1 += x1 * A1[1];
+               y2  += x0 * A0[2];
+               yy2 += x1 * A1[2];
+               y3  += x0 * A0[3];
+               yy3 += x1 * A1[3];
+               break;
+            case 3:
+               x0 = *x; x1 = x[1]; x2 = x[2];
+               y0  += x0 * *A0;
+               yy0 += x1 * *A1;
+               y1  += x0 * A0[1];
+               yy1 += x1 * A1[1];
+               y2  += x0 * A0[2];
+               yy2 += x1 * A1[2];
+               y3  += x0 * A0[3];
+               yy3 += x1 * A1[3];
+               y0 += x2 * *A2;
+               y1 += x2 * A2[1];
+               y2 += x2 * A2[2];
+               y3 += x2 * A2[3];
+               break;
+            default:;
             }
-            else /* nr == 5 */
-            {
-               y0 += m0;
-               m0 = x0 * a20;
-               a20 = A0[2];
-               z0 += m1;
-               m1 = x1 * a21;
-               a21 = A1[2];
-               y1 += m2;
-               m2 = x0 * a30;
-               x0 = *x;
-               a30 = A0[3];
-               A0 += incA;
-               z1 += m3;
-               m3 = x1 * a31;
-               x1 = x[1];
-               x += 2;
-               a31 = A1[3];
-
-               y2 += m0;
-               m0 = x0 * a00;
-               a00 = *A0;
-               z2 += m1;
-               m1 = x1 * a01;
-               y3 += m2;
-               m2 = x0 * a10;
-               a10 = A0[1];
-               z3 += m3;
-               m3 = x1 * a11;
-
-               y0 += m0;
-               m0 = x0 * a20;
-               a20 = A0[2];
-               z0 += m1;
-               m1 = x1 * a21;
-               y1 += m2;
-               m2 = x0 * a30;
-               x0 = *x;
-               a30 = A0[3];
-               z1 += m3;
-               m3 = x1 * a31;
-
-               y2 += m0;
-               m0 = x0 * a00;
-               z2 += m1;
-               m1 = x0 * a10;
-               y3 += m2;
-               m2 = x0 * a20;
-               z3 += m3;
-               m3 = x0 * a30;
-
-               y0 += m0;
-               A1 += incA;
-               y1 += m1;
-               y2 += m2;
-               y3 += m3;
-            }
-
-            y0 += z0;
             A0 += incAm;
-            y1 += z1;
+            y0 += yy0;
             A1 += incAm;
-            y2 += z2;
-            y3 += z3;
+            y1 += yy1;
+            A2 += incAm;
+            y2 += yy2;
+            A3 += incAm;
+            y3 += yy3;
             *Y = y0;
             Y[1] = y1;
             Y[2] = y2;
@@ -625,21 +555,14 @@ void Mjoin(Mjoin(Mjoin(Mjoin(Mjoin(PATL,gemvN),NM),_x1),BNM),_y1)
          }
          while (Y != stY);
       }
-      for (nr=M-m4; nr; nr--)
-      {
-         #ifdef BETA0
-            y0 = Mjoin(PATL,dot)(N, A0, lda, X, 1);
-         #else
-            #if defined(BETAX)
-               y0 = *Y * beta;
-            #else
-               y0 = *Y;
-            #endif
-            y0 += Mjoin(PATL,dot)(N, A0, lda, X, 1);
-         #endif
-         *Y++ = y0;
-         A0++;
-      }
+      if (M-M4) gemvMlt8(M-M4, N, A0, lda, X, beta, Y);
    }
    else if (M) gemvNle4(M, N, A, lda, X, beta, Y);
 }
+
+void Mjoin(Mjoin(Mjoin(Mjoin(Mjoin(PATL,gemvN),NM),_x1),BNM),_y1)
+   (const int M, const int N, const SCALAR alpha, const TYPE *A, const int lda,
+    const TYPE *X, const int incX, const SCALAR beta, TYPE *Y, const int incY)
+{
+   gemv4x4(M, N, A, lda, X, beta, Y);
+}
