@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.4.0
+ *             Automatically Tuned Linear Algebra Software v3.5.0
  *                      (C) Copyright 1999 Camm Maguire
  *
  * Redistribution and use in source and binary forms, with or without
@@ -28,6 +28,9 @@
  *
  */
 
+#ifndef ATL_GAS_x8632
+   #error "This kernel requires gas x86-32 assembler!"
+#endif
 #ifdef SREAL
    #define STRIDE 1
    #define LUNROLL 32
