@@ -18,24 +18,27 @@ static void SSQ(const int N, const TYPE *X, const int incX,
       else return;
    }
 
-   do
+   if (X != stX)
    {
-      ax = fabs(*X);
-      X += incX;
-      if (scal >= ax)
+      do
       {
-         t0 = ax / scal;
-         ssq += t0*t0;
-      }
-      else
-      {
-         t0 = scal / ax;
-         t0 *= t0;
-         ssq = ATL_rone + ssq * t0;
-         scal = ax;
+         ax = fabs(*X);
+         X += incX;
+         if (scal >= ax)
+         {
+            t0 = ax / scal;
+            ssq += t0*t0;
+         }
+         else
+         {
+            t0 = scal / ax;
+            t0 *= t0;
+            ssq = ATL_rone + ssq * t0;
+            scal = ax;
+         }
       }
+      while (X != stX);
    }
-   while (X != stX);
    *ssq0 = ssq;
    *scal0 = scal;
 }
