@@ -66,7 +66,7 @@ static TYPE RecipScal(TYPE scal)
    mant = frexp(scal, &iexp);
    mant = 0.5 / mant;
    mant = frexp(mant, &j);
-   iexp = 1 - iexp - j;
+   iexp = 1 + j - iexp;
    if (Mabs(iexp) < maxexp) rscal = ldexp(mant, iexp);
    return(rscal);
 }
